@@ -1,7 +1,12 @@
-from .NotifyMethods import *
-from .NotifyDecorators import time_func
+"""Print Messages to console
+Setup:
+    None necessary
 
-class PrintMethod(NotifyMethods):
+"""
+import FuncNotify.NotifyMethods as NotifyMethods # Using the predefined functions from the abstract class
+# import FuncNotify.NotifyDecorators as NotifyDecorators // Not used
+
+class PrintMethod(NotifyMethods.NotifyMethods):
     """Default print message, only notification is a print in terminal
     """    
 
