@@ -1,11 +1,17 @@
-from .NotifyMethods import * # Using the predefined functions from the abstract class
-from .NotifyDecorators import time_func
+"""Sends a message to any teams channel via the requests library
+
+Setup
+    1. Grab a webhook url for the specific channel: https://docs.microsoft.com/en-us/microsoftteams/platform/webhooks-and-connectors/how-to/add-incoming-webhook
+    2. Add the url and a username to .env
+"""
+import FuncNotify.NotifyMethods as NotifyMethods # Using the predefined functions from the abstract class
+import FuncNotify.NotifyDecorators as NotifyDecorators
 
 # Specify here other Packages to be imported specific for `Teams`. Include why each package is here
 import json
 import requests
 
-def time_Teams(func=None, use_env: bool=True, env_path: str=".env", update_env: bool=False,  username: str=None, webhook_url: str=None, *args, **kwargs): # Include something to check the rest of the arguments in the word
+def time_Teams(func=None, use_env: bool=True, env_path: str=".env", update_env: bool=False,  username: str=None, webhook_url: str=None, *args, **kwargs):
     """Decorator for microsoft teams messaging
 
     Args:
@@ -13,13 +19,13 @@ def time_Teams(func=None, use_env: bool=True, env_path: str=".env", update_env:
         arguments. Defaults to None.
         use_env (str, optional): Loads .env file envionment variables. Defaults to False
         env_path (str, optional): Path to .env file. Defaults to ".env".
-        update_env (bool, optional): Whether to update the .env file to current. Always updates on \ 
+        update_env (bool, optional): Whether to update the .env file to current. Always updates on \
         initialization. Defaults to False.
         
         username (str, optional): Username of the message bot Defaults to None.
-            webhook_url (str, optional): Url for the teams channel. Defaults to None.
+        webhook_url (str, optional): Url for the teams channel. Defaults to None.
     """    
-    return time_func(func=func, NotifyMethod="Teams", use_env=use_env, env_path=env_path, update_env=update_env,  username=username, webhook_url=webhook_url,*args, **kwargs) 
+    return NotifyDecorators.time_func(*args, **kwargs, **locals(), NotifyMethod="Teams") 
 
 class TeamsMethod(NotifyMethods):
     """Sends a posted message to the webhook url from the specified username. Uses standard get and post requests.
